@@ -256,7 +256,7 @@ protected :
     void sbr_envelope                       (bool ch, bool bs_coupling);
     void sbr_noise                          (bool ch, bool bs_coupling);
     void sbr_sinusoidal_coding              (bool ch);
-    int16u sbr_huff_dec                     (sbr_huffman Table, const char* Name);
+    int16u sbr_huff_dec                     (const sbr_huffman& Table, const char* Name);
 
     //Elements - SBR - PS
     void ps_data                            (size_t End);
