@@ -35,7 +35,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-int32u Pcm_VOB_BitDepth[]=
+static int32u Pcm_VOB_BitDepth[]=
 {
     16,
     20,
@@ -44,7 +44,7 @@ int32u Pcm_VOB_BitDepth[]=
 };
 
 //---------------------------------------------------------------------------
-int32u Pcm_VOB_Frequency[]=
+static int32u Pcm_VOB_Frequency[]=
 {
     48000,
     32000,
