@@ -53,6 +53,10 @@ File_SmpteSt0302::File_SmpteSt0302()
     #endif //MEDIAINFO_EVENTS
     PTS_DTS_Needed=true;
     IsRawStream=true;
+    #if MEDIAINFO_EVENTS
+        pid=(int16u)-1;
+        stream_id=(int8u)-1;
+    #endif MEDIAINFO_EVENTS
 }
 
 //---------------------------------------------------------------------------
@@ -69,6 +73,7 @@ File_SmpteSt0302::~File_SmpteSt0302()
 //---------------------------------------------------------------------------
 void File_SmpteSt0302::Streams_Accept()
 {
+#ifdef MEDIAINFO_SMPTEST0337_YES
     // SMPTE ST 337
     {
         File_SmpteSt0337* SmpteSt0337=new File_SmpteSt0337();
@@ -83,9 +88,13 @@ void File_SmpteSt0302::Streams_Accept()
                 SmpteSt0337->Demux_UnpacketizeContainer=true;
             }
         #endif //MEDIAINFO_DEMUX
+        #if MEDIAINFO_EVENTS
+            SmpteSt0337->IgnoreGuardBandTest=true;
+        #endif //MEDIAINFO_EVENTS
         Parsers.push_back(SmpteSt0337);
     }
-
+#endif // MEDIAINFO_SMPTEST0337_YES
+#ifdef MEDIAINFO_PCM_YES
     // Raw PCM
     {
         File_Pcm* Pcm=new File_Pcm();
@@ -108,6 +117,7 @@ void File_SmpteSt0302::Streams_Accept()
     // Init
     for (size_t Pos=0; Pos<Parsers.size(); Pos++)
         Open_Buffer_Init(Parsers[Pos]);
+#endif // MEDIAINFO_PCM_YES
 
     //Time stamps
     Frequency_b=48000;
