@@ -669,6 +669,8 @@ enum video
     Video_Colorimetry,
     Video_ColorSpace,
     Video_ChromaSubsampling,
+    Video_ChromaSubsampling_String,
+    Video_ChromaSubsampling_Position,
     Video_BitDepth,
     Video_BitDepth_String,
     Video_ScanType,
@@ -1380,6 +1382,41 @@ enum other
     Other_FrameRate_Num,
     Other_FrameRate_Den,
     Other_FrameCount,
+    Other_Delay,
+    Other_Delay_String,
+    Other_Delay_String1,
+    Other_Delay_String2,
+    Other_Delay_String3,
+    Other_Delay_String4,
+    Other_Delay_String5,
+    Other_Delay_Settings,
+    Other_Delay_DropFrame,
+    Other_Delay_Source,
+    Other_Delay_Source_String,
+    Other_Delay_Original,
+    Other_Delay_Original_String,
+    Other_Delay_Original_String1,
+    Other_Delay_Original_String2,
+    Other_Delay_Original_String3,
+    Other_Delay_Original_String4,
+    Other_Delay_Original_String5,
+    Other_Delay_Original_Settings,
+    Other_Delay_Original_DropFrame,
+    Other_Delay_Original_Source,
+    Other_Video_Delay,
+    Other_Video_Delay_String,
+    Other_Video_Delay_String1,
+    Other_Video_Delay_String2,
+    Other_Video_Delay_String3,
+    Other_Video_Delay_String4,
+    Other_Video_Delay_String5,
+    Other_Video0_Delay,
+    Other_Video0_Delay_String,
+    Other_Video0_Delay_String1,
+    Other_Video0_Delay_String2,
+    Other_Video0_Delay_String3,
+    Other_Video0_Delay_String4,
+    Other_Video0_Delay_String5,
     Other_TimeStamp_FirstFrame,
     Other_TimeStamp_FirstFrame_String,
     Other_TimeStamp_FirstFrame_String1,
