@@ -55,7 +55,7 @@ public :
     //***************************************************************************
 
     //In
-    Ztring ParserName;
+    std::string ParserName;
     #if MEDIAINFO_EVENTS
         size_t  StreamIDs_Size;
         int64u  StreamIDs[16];
@@ -147,6 +147,20 @@ public :
         };
         servicedescriptors* ServiceDescriptors;
     #endif
+    #if defined(MEDIAINFO_TELETEXT_YES)
+        struct teletext
+        {
+            std::map<std::string, Ztring>           Infos;
+            stream_t                                StreamKind;
+            size_t                                  StreamPos;
+
+            teletext()
+                : StreamKind(Stream_Max)
+                , StreamPos((size_t)-1)
+            {}
+        };
+        std::map<int16u, teletext>*                 Teletexts; //Key is teletext_magazine_number
+    #endif
 
     //Out
     int64u PTS_Begin;                  //In nanoseconds
@@ -319,7 +333,6 @@ protected :
 protected :
     //Element - Common
     void   Element_End_Common_Flush();
-    Ztring Element_End_Common_Flush_Build();
 public :
 
     //***************************************************************************
@@ -327,24 +340,25 @@ public :
     //***************************************************************************
 
     //Param - Main
-    #define Param1(_A)
-    #define Param2(_A,_B)
-    #define Param3(_A,_B,_C)
+    inline void noop() {}
+    #define Param1(_A) noop()
+    #define Param2(_A,_B) noop()
+    #define Param3(_A,_B,_C) noop()
 
     //Param - Info
-    #define Param_Info1(_A)
-    #define Param_Info2(_A,_B)
-    #define Param_Info3(_A,_B,_C)
-    #define Param_Info1C(_CONDITION,_A)
-    #define Param_Info2C(_CONDITION,_A,_B)
-    #define Param_Info3C(_CONDITION,_A,_B,_C)
-    #define Param_Info_From_Milliseconds(A)
+    #define Param_Info1(_A) noop()
+    #define Param_Info2(_A,_B) noop()
+    #define Param_Info3(_A,_B,_C) noop()
+    #define Param_Info1C(_CONDITION,_A) noop()
+    #define Param_Info2C(_CONDITION,_A,_B) noop()
+    #define Param_Info3C(_CONDITION,_A,_B,_C) noop()
+    #define Param_Info_From_Milliseconds(A) noop()
 
     //***************************************************************************
     // Information
     //***************************************************************************
 
-    inline void Info (const Ztring&, size_t =0) {}
+    inline void Info (const std::string&, size_t =0) {}
 
     //***************************************************************************
     // Big Endian (Integer, Float, Fixed-Point)
@@ -1041,7 +1055,12 @@ public :
     #ifdef SIZE_T_IS_LONG
     inline void Fill (stream_t StreamKind, size_t StreamPos, const char* Parameter, size_t         Value, int8u Radix=10, bool Replace=false) {Fill(StreamKind, StreamPos, Parameter, Ztring::ToZtring(Value, Radix).MakeUpperCase(), Replace);}
     #endif //SIZE_T_IS_LONG
-    ZtringListList Fill_Temp;
+    struct fill_temp_item
+    {
+        Ztring Parameter;
+        Ztring Value;
+    };
+    vector<fill_temp_item> Fill_Temp[Stream_Max+1]; // +1 because Fill_Temp[Stream_Max] is used when StreamKind is unknown
     void Fill_Flush ();
     static size_t Fill_Parameter(stream_t StreamKind, generic StreamPos);
 
@@ -1114,6 +1133,10 @@ public :
     void CodecID_Fill           (const Ztring &Value, stream_t StreamKind, size_t StreamPos, infocodecid_format_t Format, stream_t StreamKind_CodecID=Stream_Max);
     void PixelAspectRatio_Fill  (const Ztring &Value, stream_t StreamKind, size_t StreamPos, size_t Parameter_Width, size_t Parameter_Height, size_t Parameter_PixelAspectRatio, size_t Parameter_DisplayAspectRatio);
     void DisplayAspectRatio_Fill(const Ztring &Value, stream_t StreamKind, size_t StreamPos, size_t Parameter_Width, size_t Parameter_Height, size_t Parameter_PixelAspectRatio, size_t Parameter_DisplayAspectRatio);
+    #if MEDIAINFO_EVENTS
+    static stream_t Streamkind_Get(int8u* ParserIDs, size_t StreamIDs_Size) {if ((ParserIDs[StreamIDs_Size-1]&0xF0)==0x80) return Stream_Video; if ((ParserIDs[StreamIDs_Size-1]&0xF0)==0xA0) return Stream_Audio; return Stream_Max;}
+    stream_t Streamkind_Get() {return Streamkind_Get(ParserIDs, StreamIDs_Size);}
+    #endif //MEDIAINFO_EVENTS
 
     //***************************************************************************
     // Finalize
@@ -1225,6 +1248,9 @@ protected :
     bool Synchronize_0x000001();
 public:
     void TestContinuousFileNames(size_t CountOfFiles=24, Ztring FileExtension=Ztring(), bool SkipComputeDelay=false);
+    #if MEDIAINFO_FIXITY
+    bool FixFile(int64u FileOffsetForWriting, const int8u* ToWrite, const size_t ToWrite_Size);
+    #endif// MEDIAINFO_FIXITY
 
 private :
 
@@ -1233,9 +1259,9 @@ private :
     //***************************************************************************
 
     //Element
+public: //TO CHANGE
     BitStream_Fast* BS;             //For conversion from bytes to bitstream
     BitStream*      BT;             //For conversion from bytes to bitstream (Little Endian)
-public : //TO CHANGE
     int64u Header_Size;             //Size of the header of the current element
 private :
 
