@@ -61,6 +61,7 @@ namespace Elements
     const int16u QCD =0xFF5C; //JPEG 2000
     const int16u QCC =0xFF5D; //JPEG 2000
     const int16u RGN =0xFF5E; //JPEG 2000
+    const int16u POC =0xFF5F; //JPEG 2000
     const int16u PPM =0xFF60; //JPEG 2000
     const int16u PPT =0xFF61; //JPEG 2000
     const int16u CME =0xFF64; //JPEG 2000
@@ -142,6 +143,31 @@ struct Jpeg_samplingfactor
     int8u Vi;
 };
 
+//---------------------------------------------------------------------------
+string Jpeg2000_Rsiz(int16u Rsiz)
+{
+    switch (Rsiz)
+    {
+        case 0x0000: return "No restrictions";
+        case 0x0001: return "Profile-0";
+        case 0x0002: return "Profile-1";
+        case 0x0003: return "D-Cinema 2k";
+        case 0x0004: return "D-Cinema 4k";
+        case 0x0005: return "D-Cinema 2k Scalable";
+        case 0x0006: return "D-Cinema 4k Scalable";
+        case 0x0007: return "Long-term storage";
+        case 0x0101: return "BCS@L1"; //Broadcast Contribution Single Tile
+        case 0x0102: return "BCS@L2"; //Broadcast Contribution Single Tile
+        case 0x0103: return "BCS@L3"; //Broadcast Contribution Single Tile
+        case 0x0104: return "BCS@L4"; //Broadcast Contribution Single Tile
+        case 0x0105: return "BCS@L5"; //Broadcast Contribution Single Tile
+        case 0x0205: return "BCM@L5"; //Broadcast Contribution Multi-tile
+        case 0x0306: return "BCMR@L6"; //Broadcast Contribution Multi-tile Reversible
+        case 0x0307: return "BCMR@L7"; //Broadcast Contribution Multi-tile Reversible
+        default: return Ztring::ToZtring(Rsiz, 16).To_UTF8();
+    }
+}
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -163,6 +189,9 @@ File_Jpeg::File_Jpeg()
     //In
     StreamKind=Stream_Image;
     Interlaced=false;
+    #if MEDIAINFO_DEMUX
+    FrameRate=0;
+    #endif //MEDIAINFO_DEMUX
 }
 
 //***************************************************************************
@@ -177,7 +206,8 @@ void File_Jpeg::Streams_Accept()
         TestContinuousFileNames();
 
         Stream_Prepare(Config->File_Names.size()>1?Stream_Video:StreamKind);
-        Fill(StreamKind_Last, StreamPos_Last, "StreamSize", File_Size);
+        if (File_Size!=(int64u)-1)
+            Fill(StreamKind_Last, StreamPos_Last, Fill_Parameter(StreamKind_Last, Generic_StreamSize), File_Size);
         if (StreamKind_Last==Stream_Video)
             Fill(Stream_Video, StreamPos_Last, Video_FrameCount, Config->File_Names.size());
     }
@@ -186,7 +216,6 @@ void File_Jpeg::Streams_Accept()
 
     //Configuration
     Buffer_MaximumSize=64*1024*1024; //Some big frames are possible (e.g YUV 4:2:2 10 bits 1080p)
-    Frame_Count_NotParsedIncluded=0;
 }
 
 //---------------------------------------------------------------------------
@@ -271,6 +300,96 @@ void File_Jpeg::Synched_Init()
     APPE_Adobe0_transform=(int8u)-1;
 }
 
+//***************************************************************************
+// Buffer - Demux
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_DEMUX
+bool File_Jpeg::Demux_UnpacketizeContainer_Test()
+{
+    if (!IsSub)
+    {
+        if (!Status[IsAccepted])
+            Accept();
+        if (Config->File_Names.size()>1)
+            return Demux_UnpacketizeContainer_Test_OneFramePerFile();
+    }
+
+    if (Interlaced && Buffer_Offset==0)
+    {
+        bool StartIsFound=false;
+        while (Demux_Offset+2<=Buffer_Size)
+        {
+            int16u code=BigEndian2int16u(Buffer+Demux_Offset);
+            Demux_Offset+=2;
+            switch (code)
+            {
+                case Elements::SOD  :   //JPEG-2000 start
+                                        StartIsFound=true;
+                case Elements::TEM  :
+                case Elements::RST0 :
+                case Elements::RST1 :
+                case Elements::RST2 :
+                case Elements::RST3 :
+                case Elements::RST4 :
+                case Elements::RST5 :
+                case Elements::RST6 :
+                case Elements::RST7 :
+                case Elements::SOC  :
+                case Elements::SOI  :
+                case Elements::EOI  :
+                             break;
+                default   :
+                            if (Demux_Offset+2>Buffer_Size)
+                                break;
+                            {
+                            int16u size=BigEndian2int16u(Buffer+Demux_Offset);
+                            if (Demux_Offset+2+size>Buffer_Size)
+                                break;
+                            Demux_Offset+=size;
+                            if (code==Elements::SOS) //JPEG start
+                                StartIsFound=true;
+                            }
+            }
+            if (StartIsFound)
+                break;
+        }
+
+        while (Demux_Offset+2<=Buffer_Size)
+        {
+            while (Demux_Offset<Buffer_Size && Buffer[Demux_Offset]!=0xFF)
+                Demux_Offset++;
+            if (Demux_Offset+2<=Buffer_Size && Buffer[Demux_Offset+1]==0xD9) //EOI (JPEG 2000)
+                break;
+            Demux_Offset++;
+        }
+        if (Demux_Offset+2<=Buffer_Size)
+            Demux_Offset+=2;
+    }
+    else
+        Demux_Offset=Buffer_Size;
+
+    if (Interlaced)
+    {
+        if (Field_Count==0 && FrameRate && Demux_Offset!=Buffer_Size)
+            FrameRate*=2; //Now field rate
+        if (FrameRate)
+            FrameInfo.DUR=float64_int64s(1000000000/FrameRate); //Actually, field or frame rate
+    }
+
+    Demux_UnpacketizeContainer_Demux();
+
+    if (Interlaced)
+    {
+        if (FrameInfo.DTS!=(int64u)-1 && FrameInfo.DUR!=(int64u)-1)
+            FrameInfo.DTS+=FrameInfo.DUR;
+    }
+
+    return true;
+}
+#endif //MEDIAINFO_DEMUX
+
 //***************************************************************************
 // Buffer - Global
 //***************************************************************************
@@ -283,6 +402,46 @@ void File_Jpeg::Read_Buffer_Unsynched()
     Read_Buffer_Unsynched_OneFramePerFile();
 }
 
+//---------------------------------------------------------------------------
+void File_Jpeg::Read_Buffer_Continue()
+{
+    if (Config->ParseSpeed>=1.0 && IsSub && Status[IsFilled])
+    {
+        #if MEDIAINFO_DEMUX
+            if (Buffer_TotalBytes<Demux_TotalBytes)
+            {
+                Skip_XX(Demux_TotalBytes-Buffer_TotalBytes,     "Data"); //We currently don't want to parse data during demux
+                Param_Info1(Frame_Count);
+                if (Interlaced)
+                {
+                    Field_Count++;
+                    Field_Count_InThisBlock++;
+                }
+                if (!Interlaced || Field_Count%2==0)
+                {
+                    Frame_Count++;
+                    if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+                        Frame_Count_NotParsedIncluded++;
+                }
+                return;
+            }
+        #endif //MEDIAINFO_DEMUX
+
+        #if MEDIAINFO_DEMUX
+        if (!Demux_UnpacketizeContainer)
+        #endif //MEDIAINFO_DEMUX
+        {
+            Skip_XX(Buffer_Size,                                    "Data"); //We currently don't want to parse data during demux
+            Param_Info1(Frame_Count);
+            if (Interlaced)
+                Field_Count+=2;
+            Frame_Count++;
+            if (Frame_Count_NotParsedIncluded!=(int64u)-1)
+                Frame_Count_NotParsedIncluded++;
+        }
+    }
+}
+
 //***************************************************************************
 // Buffer - Per element
 //***************************************************************************
@@ -334,9 +493,20 @@ bool File_Jpeg::Header_Parser_Fill_Size()
     //Look for next Sync word
     if (Buffer_Offset_Temp==0) //Buffer_Offset_Temp is not 0 if Header_Parse_Fill_Size() has already parsed first frames
         Buffer_Offset_Temp=Buffer_Offset;
-    while (Buffer_Offset_Temp+2<=Buffer_Size
-        && CC2(Buffer+Buffer_Offset_Temp)!=Elements::EOI)
+
+    #if MEDIAINFO_DEMUX
+        if (Buffer_TotalBytes+2<Demux_TotalBytes)
+            Buffer_Offset_Temp=(size_t)(Demux_TotalBytes-(Buffer_TotalBytes+2));
+    #endif //MEDIAINFO_DEMUX
+
+    while (Buffer_Offset_Temp+2<=Buffer_Size)
+    {
+        while (Buffer_Offset_Temp<Buffer_Size && Buffer[Buffer_Offset_Temp]!=0xFF)
+            Buffer_Offset_Temp++;
+        if (Buffer_Offset_Temp+2<=Buffer_Size && Buffer[Buffer_Offset_Temp+1]==0xD9) //EOI
+            break;
         Buffer_Offset_Temp++;
+    }
 
     //Must wait more data?
     if (Buffer_Offset_Temp+2>Buffer_Size)
@@ -379,6 +549,7 @@ void File_Jpeg::Data_Parse()
         CASE_INFO(QCD ,                                         "Quantization default"); //JPEG 2000
         CASE_INFO(QCC ,                                         "Quantization component "); //JPEG 2000
         CASE_INFO(RGN ,                                         "Region-of-interest"); //JPEG 2000
+        CASE_INFO(POC ,                                         "Progression order change"); //JPEG 2000
         CASE_INFO(PPM ,                                         "Packed packet headers, main header"); //JPEG 2000
         CASE_INFO(PPT ,                                         "Packed packet headers, tile-part header"); //JPEG 2000
         CASE_INFO(CME ,                                         "Comment and extension"); //JPEG 2000
@@ -466,8 +637,8 @@ void File_Jpeg::SIZ()
     vector<int8u> BitDepths;
     int8u SamplingFactors_Max=0;
     int32u Xsiz, Ysiz;
-    int16u Count;
-    Skip_B2(                                                    "Rsiz - Capability of the codestream");
+    int16u Rsiz, Count;
+    Get_B2 (Rsiz,                                               "Rsiz - Capability of the codestream");
     Get_B4 (Xsiz,                                               "Xsiz - Image size X");
     Get_B4 (Ysiz,                                               "Ysiz - Image size Y");
     Skip_B4(                                                    "XOsiz - Image offset X");
@@ -511,6 +682,7 @@ void File_Jpeg::SIZ()
                 Stream_Prepare(StreamKind_Last);
             Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Format), "JPEG 2000");
             Fill(StreamKind_Last, 0, Fill_Parameter(StreamKind_Last, Generic_Codec), "JPEG 2000");
+            Fill(StreamKind_Last, 0, "Format_Profile", Jpeg2000_Rsiz(Rsiz));
             if (StreamKind_Last==Stream_Image)
                 Fill(Stream_Image, 0, Image_Codec_String, "JPEG 2000", Unlimited, true, true); //To Avoid automatic filling
             Fill(StreamKind_Last, 0, StreamKind_Last==Stream_Image?(size_t)Image_Width:(size_t)Video_Width, Xsiz);
@@ -536,6 +708,17 @@ void File_Jpeg::SIZ()
             {
                 ChromaSubsampling.resize(ChromaSubsampling.size()-1);
                 Fill(StreamKind_Last, 0, "ChromaSubsampling", ChromaSubsampling);
+
+                //Not for sure
+                if (ChromaSubsampling==__T("4:4:4") && (Retrieve(StreamKind_Last, 0, "Format_Profile")==__T("D-Cinema 2k") || Retrieve(StreamKind_Last, 0, "Format_Profile")==__T("D-Cinema 4k")))
+                    Fill(StreamKind_Last, 0, "ColorSpace", "XYZ");
+                else if (!IsSub)
+                {
+                    if (ChromaSubsampling==__T("4:2:0") || ChromaSubsampling==__T("4:2:2"))
+                        Fill(StreamKind_Last, 0, "ColorSpace", "YUV");
+                    else if (ChromaSubsampling==__T("4:4:4"))
+                        Fill(StreamKind_Last, 0, "ColorSpace", "RGB");
+                }
             }
         }
     FILLING_END();
@@ -676,6 +859,7 @@ void File_Jpeg::SOF_()
                 case 0x01 :
                             if (Count==3)
                                 Fill(StreamKind_Last, 0, "ColorSpace", "YUV");
+                            break;
                 case 0x02 :
                             if (Count==4)
                                 Fill(StreamKind_Last, 0, "ColorSpace", "YCCB");
@@ -744,6 +928,7 @@ void File_Jpeg::SOF_()
                             switch (SamplingFactors[0].Vi)
                             {
                                 case 1 : ChromaSubsampling="4:1:1"; break;
+                                case 2 : ChromaSubsampling="4:1:0"; break;
                                 default: ;
                             }
                             break;
@@ -817,43 +1002,52 @@ void File_Jpeg::APP0()
 }
 
 //---------------------------------------------------------------------------
+// From OpenDML AVI File Format Extensions
 void File_Jpeg::APP0_AVI1()
 {
     Element_Info1("AVI1");
 
     //Parsing
+    bool UnknownInterlacement_IsDetected=false;
     int8u  FieldOrder=(int8u)-1;
-    if (Element_Size==16-4)
+    Get_B1 (FieldOrder,                                         "Polarity");
+    if (Element_Size>=14)
     {
-        Get_B1 (FieldOrder,                                     "Polarity");
-        Skip_XX(7,                                              "Zeroes");
-    }
-    if (Element_Size==18-4)
-    {
-        int32u FieldSizeLessPadding;
-        Get_B1 (FieldOrder,                                     "Field Order");
-        Skip_B1(                                                "Zero");
-        Skip_B4(                                                "FieldSize");
+        int32u FieldSize, FieldSizeLessPadding;
+        Skip_B1(                                                "Reserved");
+        Get_B4 (FieldSize,                                      "FieldSize");
         Get_B4 (FieldSizeLessPadding,                           "FieldSizeLessPadding");
 
         //Coherency
-        if (FieldOrder==0 && IsSub && FieldSizeLessPadding!=Buffer_Size)
-            FieldOrder=(int8u)-1; //Not coherant
+        if (FieldOrder==0 && IsSub && FieldSize && FieldSize!=Buffer_Size)
+        {
+            if (FieldSizeLessPadding>1 && FieldSizeLessPadding<=Buffer_Size && Buffer[FieldSizeLessPadding-2]==0xFF && Buffer[FieldSizeLessPadding-1]==0xD9  //EOI
+             &&                           FieldSize+1         < Buffer_Size && Buffer[FieldSize]             ==0xFF && Buffer[FieldSize+1]           ==0xD8) //SOI
+                UnknownInterlacement_IsDetected=true;
+        }
     }
+    Skip_XX(Element_Size-Element_Offset,                        "Unknown");
 
     FILLING_BEGIN();
         if (Frame_Count==0 && Field_Count==0)
         {
             Accept();
 
+            if (UnknownInterlacement_IsDetected)
+            {
+                Fill(Stream_Video, 0, Video_ScanType, "Interlaced");
+                Interlaced=true;
+            }
+            else
+            {
             switch (FieldOrder)
             {
                 case 0x00 : Fill(Stream_Video, 0, Video_Interlacement, "PPF"); Fill(Stream_Video, 0, Video_ScanType, "Progressive"); break;
                 case 0x01 : Fill(Stream_Video, 0, Video_Interlacement, "TFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "TFF"); Interlaced=true; break;
                 case 0x02 : Fill(Stream_Video, 0, Video_Interlacement, "BFF"); Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Fill(Stream_Video, 0, Video_ScanOrder, "BFF"); Interlaced=true; break;
-                case 0xFF : Fill(Stream_Video, 0, Video_ScanType, "Interlaced"); Interlaced=true; break;
                 default   : ;
             }
+            }
         }
     FILLING_END();
 }
