@@ -200,6 +200,9 @@
 #if defined(MEDIAINFO_AU_YES)
     #include "MediaInfo/Audio/File_Au.h"
 #endif
+#if defined(MEDIAINFO_CAF_YES)
+    #include "MediaInfo/Audio/File_Caf.h"
+#endif
 #if defined(MEDIAINFO_DTS_YES)
     #include "MediaInfo/Audio/File_Dts.h"
 #endif
@@ -242,9 +245,6 @@
 #if defined(MEDIAINFO_SMPTEST0337_YES)
     #include "MediaInfo/Audio/File_SmpteSt0337.h"
 #endif
-#if defined(MEDIAINFO_RKAU_YES)
-    #include "MediaInfo/Audio/File_Rkau.h"
-#endif
 #if defined(MEDIAINFO_TAK_YES)
     #include "MediaInfo/Audio/File_Tak.h"
 #endif
@@ -275,9 +275,15 @@
 #if defined(MEDIAINFO_SCC_YES)
     #include "MediaInfo/Text/File_Scc.h"
 #endif
+#if defined(MEDIAINFO_SDP_YES)
+    #include "MediaInfo/Text/File_Sdp.h"
+#endif
 #if defined(MEDIAINFO_SUBRIP_YES)
     #include "MediaInfo/Text/File_SubRip.h"
 #endif
+#if defined(MEDIAINFO_TELETEXT_YES)
+    #include "MediaInfo/Text/File_Teletext.h"
+#endif
 #if defined(MEDIAINFO_TTML_YES)
     #include "MediaInfo/Text/File_Ttml.h"
 #endif
@@ -293,6 +299,9 @@
 #if defined(MEDIAINFO_BMP_YES)
     #include "MediaInfo/Image/File_Bmp.h"
 #endif
+#if defined(MEDIAINFO_BPG_YES)
+    #include "MediaInfo/Image/File_Bpg.h"
+#endif
 #if defined(MEDIAINFO_DDS_YES)
     #include "MediaInfo/Image/File_Dds.h"
 #endif
@@ -416,6 +425,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_DCP_YES)
         else if (Parser==__T("DcpPkg"))      Info=new File_DcpPkl();
     #endif
+    #if defined(MEDIAINFO_DPG_YES)
+        else if (Parser==__T("Dpg"))         Info=new File_Dpg();
+    #endif
     #if defined(MEDIAINFO_DVDIF_YES)
         else if (Parser==__T("DvDif"))        Info=new File_DvDif();
     #endif
@@ -437,12 +449,12 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_HLS_YES)
         else if (Parser==__T("Hls"))         Info=new File_Hls();
     #endif
-    #if defined(MEDIAINFO_IVF_YES)
-        else if (Parser==__T("Ivf"))         Info=new File_Ivf();
-    #endif
     #if defined(MEDIAINFO_ISM_YES)
         else if (Parser==__T("Ism"))         Info=new File_Ism();
     #endif
+    #if defined(MEDIAINFO_IVF_YES)
+        else if (Parser==__T("Ivf"))         Info=new File_Ivf();
+    #endif
     #if defined(MEDIAINFO_LXF_YES)
         else if (Parser==__T("Lxf"))         Info=new File_Lxf();
     #endif
@@ -497,9 +509,6 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_XDCAM_YES)
         else if (Parser==__T("Xdcam_Clip"))   Info=new File_Xdcam_Clip();
     #endif
-    #if defined(MEDIAINFO_DPG_YES)
-        else if (Parser==__T("Dpg"))         Info=new File_Dpg();
-    #endif
 
     // Video
     #if defined(MEDIAINFO_AVC_YES)
@@ -561,6 +570,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_AU_YES)
         else if (Parser==__T("Au"))          Info=new File_Au();
     #endif
+    #if defined(MEDIAINFO_CAF_YES)
+        else if (Parser==__T("Caf"))          Info=new File_Caf();
+    #endif
     #if defined(MEDIAINFO_DTS_YES)
         else if (Parser==__T("Dts"))         Info=new File_Dts();
     #endif
@@ -594,11 +606,8 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_OPENMG_YES)
         else if (Parser==__T("OpenMG"))      Info=new File_OpenMG();
     #endif
-    #if defined(MEDIAINFO_AU_YES)
-        else if (Parser==__T("Au"))          Info=new File_Au();
-    #endif
     #if defined(MEDIAINFO_RKAU_YES)
-        else if (Parser==__T("Rkau"))         Info=new File_Rkau();
+        else if (Parser==__T("Rkau"))        Info=new File_Rkau();
     #endif
     #if defined(MEDIAINFO_S3M_YES)
         else if (Parser==__T("S3m"))         Info=new File_ScreamTracker3();
@@ -633,10 +642,16 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_SCC_YES)
         else if (Parser==__T("SCC"))         Info=new File_Scc();
     #endif
+    #if defined(MEDIAINFO_SDP_YES)
+        else if (Parser==__T("SDP"))         Info=new File_Sdp();
+    #endif
     #if defined(MEDIAINFO_SUBRIP_YES)
         else if (Parser==__T("SubRip"))      Info=new File_SubRip();
         else if (Parser==__T("WebVTT"))      Info=new File_SubRip();
     #endif
+    #if defined(MEDIAINFO_TELETEXT_YES)
+        else if (Parser==__T("Teletext"))    Info=new File_Teletext();
+    #endif
     #if defined(MEDIAINFO_TTML_YES)
         else if (Parser==__T("TTML"))        Info=new File_Ttml();
     #endif
@@ -645,15 +660,15 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #endif
 
     // Image
-    #if defined(MEDIAINFO_GIF_YES)
-        else if (Parser==__T("Gif"))         Info=new File_Gif();
-    #endif
     #if defined(MEDIAINFO_ARRIRAW_YES)
         else if (Parser==__T("Arri Raw"))    Info=new File_ArriRaw();
     #endif
     #if defined(MEDIAINFO_BMP_YES)
         else if (Parser==__T("Bmp"))         Info=new File_Bmp();
     #endif
+    #if defined(MEDIAINFO_BPG_YES)
+        else if (Parser==__T("Bpg"))         Info=new File_Bpg();
+    #endif
     #if defined(MEDIAINFO_DDS_YES)
         else if (Parser==__T("Dds"))         Info=new File_Dds();
     #endif
@@ -663,6 +678,9 @@ bool MediaInfo_Internal::SelectFromExtension (const String &Parser)
     #if defined(MEDIAINFO_EXR_YES)
         else if (Parser==__T("Exr"))         Info=new File_Exr();
     #endif
+    #if defined(MEDIAINFO_GIF_YES)
+        else if (Parser==__T("Gif"))         Info=new File_Gif();
+    #endif
     #if defined(MEDIAINFO_ICO_YES)
         else if (Parser==__T("Ico"))         Info=new File_Ico();
     #endif
@@ -912,6 +930,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_AU_YES)
         delete Info; Info=new File_Au();                 if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_CAF_YES)
+        delete Info; Info=new File_Caf();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_DTS_YES)
         delete Info; Info=new File_Dts();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -978,9 +999,15 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_SCC_YES)
         delete Info; Info=new File_Scc();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_SDP_YES)
+        delete Info; Info=new File_Sdp();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_SUBRIP_YES)
         delete Info; Info=new File_SubRip();             if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_TELETEXT_YES)
+        delete Info; Info=new File_Teletext();           if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_TTML_YES)
         delete Info; Info=new File_Ttml();               if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
@@ -995,6 +1022,9 @@ int MediaInfo_Internal::ListFormats(const String &File_Name)
     #if defined(MEDIAINFO_BMP_YES)
         delete Info; Info=new File_Bmp();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
+    #if defined(MEDIAINFO_BPG_YES)
+        delete Info; Info=new File_Bpg();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
+    #endif
     #if defined(MEDIAINFO_DDS_YES)
         delete Info; Info=new File_Dds();                if (((Reader_File*)Reader)->Format_Test_PerParser(this, File_Name)>0) return 1;
     #endif
