@@ -99,7 +99,7 @@ Ztring MediaInfo_Internal::Inform()
         if (MediaInfoLib::Config.Inform_Get()!=__T("MAXML") && (MediaInfoLib::Config.Trace_Level_Get() || MediaInfoLib::Config.Inform_Get()==__T("Details")))
         {
             if (!Details.empty())
-                return Details;
+                return Ztring().From_UTF8(Details);
             else if (Info)
                 return Info->Details_Get();
             else
@@ -108,18 +108,22 @@ Ztring MediaInfo_Internal::Inform()
     #endif //MEDIAINFO_TRACE
 
     #if defined(MEDIAINFO_EBUCORE_YES)
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.5"))
+            return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_5);
         if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.6"))
             return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_6);
-        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore") || MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.5"))
+        if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore"))
             return Export_EbuCore().Transform(*this);
     #endif //defined(MEDIAINFO_EBUCORE_YES)
     #if defined(MEDIAINFO_EBUCORE_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.1"))
             return Export_Fims().Transform(*this, Export_Fims::Version_1_1);
-        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.2") || MediaInfoLib::Config.Inform_Get()==__T("FIMS"))
+        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.2"))
             return Export_Fims().Transform(*this, Export_Fims::Version_1_2);
         if (MediaInfoLib::Config.Inform_Get()==__T("FIMS_1.3"))
             return Export_Fims().Transform(*this, Export_Fims::Version_1_3);
+        if (MediaInfoLib::Config.Inform_Get()==__T("FIMS"))
+            return Export_Fims().Transform(*this);
     #endif //defined(MEDIAINFO_FIMS_YES)
     #if defined(MEDIAINFO_MPEG7_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7"))
@@ -269,10 +273,13 @@ Ztring MediaInfo_Internal::Inform()
     if (XML_0_7_78_MA || XML_0_7_78_MI)
     {
         size_t Modified;
-        Retour+=__T("<media ref=\"")+MediaInfo_Internal::Xml_Content_Escape(Get(Stream_General, 0, General_CompleteName), Modified)+__T("\">\n");
+        Retour+=__T("<media ref=\"")+MediaInfo_Internal::Xml_Content_Escape(Get(Stream_General, 0, General_CompleteName), Modified)+= __T("\"");
+        if (Info && !Info->ParserName.empty())
+            Retour+=__T(" parser=\"")+ Ztring().From_UTF8(Info->ParserName)+=__T("\"");
+        Retour+= __T(">\n");
     }
     if (XML_0_7_78_MA)
-        Retour+=__T("<MediaInfo xmlns=\"https://mediaarea.net/mediainfo\" version=\"2.0beta1\">\n");
+        Retour+=__T("<MediaInfo xmlns=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediainfo\" version=\"2.0beta1\">\n");
     if (XML)
         Retour+=__T("<File>\n");
     #endif //defined(MEDIAINFO_XML_YES)
@@ -343,9 +350,9 @@ Ztring MediaInfo_Internal::Inform()
         {
             if (MediaInfoLib::Config.Trace_Level_Get() || MediaInfoLib::Config.Inform_Get()==__T("Details"))
             {
-                Retour+=__T("<MediaTrace xmlns=\"https://mediaarea.net/mediatrace\" version=\"0.1\">\n");
+                Retour+=__T("<MediaTrace xmlns=\"http")+(MediaInfoLib::Config.Https_Get()?Ztring(__T("s")):Ztring())+__T("://mediaarea.net/mediatrace\" version=\"0.1\">\n");
                 if (!Details.empty())
-                    Retour+=Details;
+                    Retour+=Ztring().From_UTF8(Details);
                 else if (Info)
                     Retour+=Info->Details_Get();
                 Retour+=__T("\n");
@@ -465,6 +472,22 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
                      Nom.resize(Nom_Size, ' ');
                 }
                 Ztring Valeur=Get((stream_t)StreamKind, StreamPos, Champ_Pos, Info_Text);
+
+                //Handling values with \r\n inside
+                #if defined(MEDIAINFO_TEXT_YES) && (defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES))
+                if (Text)
+                #endif //defined(MEDIAINFO_TEXT_YES) && (defined(MEDIAINFO_HTML_YES) || defined(MEDIAINFO_XML_YES) || defined(MEDIAINFO_CSV_YES))
+                {
+                    if (Valeur.find(__T('\r'))!=string::npos || Valeur.find(__T('\n'))!=string::npos)
+                    {
+                        Valeur.FindAndReplace(__T("\r\n"), __T(" / "), 0, Ztring_Recursive);
+                        Valeur.FindAndReplace(__T("\r"), __T(" / "), 0, Ztring_Recursive);
+                        Valeur.FindAndReplace(__T("\n"), __T(" / "), 0, Ztring_Recursive);
+                        if (Valeur.size()>=3 && Valeur.rfind(__T(" / "))== Valeur.size()-3)
+                            Valeur.resize(Valeur.size()-3);
+                    }
+                }
+
                 #if defined(MEDIAINFO_XML_YES)
                     if (XML_0_7_78 && MediaInfoLib::Config.Info_Get(StreamKind).Read(Champ_Pos, Info_Measure)==__T(" ms"))
                     {
@@ -566,9 +589,9 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
 
     //Gestion $xx$
     size_t PosX=0;
-    while (Retour.find(__T("$"), PosX)!=(size_t)-1)
+    while (Retour.find(__T('$'), PosX)!=(size_t)-1)
     {
-        PosX=Retour.find(__T("$"), PosX);
+        PosX=Retour.find(__T('$'), PosX);
         if (Retour.size()>PosX+2 && !(Retour(PosX+1)==__T('i') && Retour(PosX+2)==__T('f') && Retour(PosX+3)==__T('('))) //To keep out "%" without any signification, or "$if(..."
         {
             Ztring ARemplacer=Ztring(__T("$")+Retour.SubString(__T("$"), __T("$"), PosX))+__T("$");
@@ -645,9 +668,9 @@ Ztring MediaInfo_Internal::Inform (stream_t StreamKind, size_t StreamPos, bool I
 
     //Gestion %xxx%
     PosX=0;
-    while (Retour.find(__T("%"), PosX)!=(size_t)-1)
+    while (Retour.find(__T('%'), PosX)!=(size_t)-1)
     {
-        PosX=Retour.find(__T("%"), PosX);
+        PosX=Retour.find(__T('%'), PosX);
         if (Retour.size() > PosX + 2 && Retour[PosX + 1] >= __T('A') && Retour[PosX + 1] <= __T('Z')) //To keep out "%" without any signification
         {
             Ztring ARemplacer = Ztring(__T("%") + Retour.SubString(__T("%"), __T("%"), PosX)) + __T("%");
