@@ -746,7 +746,11 @@ size_t MediaInfo_Internal::Open_Buffer_Init (int64u File_Size_, int64u File_Offs
     if (Config.File_Names.size()<=1) //If analyzing multiple files, theses members are adapted in File_Reader.cpp
     {
         if (File_Size_!=(int64u)-1)
+        {
             Config.File_Size=Config.File_Current_Size=File_Size_;
+            if (Info && !Info->Retrieve(Stream_General, 0, General_FileSize).empty())
+                Info->Fill(Stream_General, 0, General_FileSize, File_Size_, 10, true); //TODO: avoid multiple tests of file size field, refactor it in order to have a single place for file size info
+        }
     }
 
     if (Info==NULL || File_Size_!=(int64u)-1)
@@ -926,6 +930,12 @@ size_t MediaInfo_Internal::Open_Buffer_Finalize ()
     {
         delete[] Config.File_Buffer; Config.File_Buffer=NULL; Config.File_Buffer_Size=0; Config.File_Buffer_Size_Max=0;
     }
+    #if MEDIAINFO_EVENTS
+        if (!Config.File_IsReferenced_Get()) //TODO: get its own metadata in order to know if it was created by this instance
+        {
+            delete Config.Config_PerPackage; Config.Config_PerPackage=NULL;
+        }
+    #endif //MEDIAINFO_EVENTS
 
     EXECUTE_SIZE_T(1, Debug+=__T("Open_Buffer_Finalize, will return 1"))
 }
@@ -1270,22 +1280,22 @@ String MediaInfo_Internal::Option (const String &Option, const String &Value)
                     Ztring FrameNumberZ=List[Pos].substr(List[Pos].find(__T("Frame="))+6, string::npos);
                     SeekValue=FrameNumberZ.To_int64u();
                 }
-                else if (!List[Pos].empty() && List[Pos].find(__T(":"))!=string::npos)
+                else if (!List[Pos].empty() && List[Pos].find(__T(':'))!=string::npos)
                 {
                     Method=2;
                     Ztring ValueZ=List[Pos];
                     SeekValue=0;
-                    size_t Value_Pos=ValueZ.find(__T(":"));
+                    size_t Value_Pos=ValueZ.find(__T(':'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*60*60*1000*1000*1000;
                     ValueZ.erase(0, Value_Pos+1);
-                    Value_Pos=ValueZ.find(__T(":"));
+                    Value_Pos=ValueZ.find(__T(':'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*60*1000*1000*1000;
                     ValueZ.erase(0, Value_Pos+1);
-                    Value_Pos=ValueZ.find(__T("."));
+                    Value_Pos=ValueZ.find(__T('.'));
                     if (Value_Pos==string::npos)
                         Value_Pos=ValueZ.size();
                     SeekValue+=Ztring(ValueZ.substr(0, Value_Pos)).To_int64u()*1000*1000*1000;
