@@ -45,7 +45,7 @@ namespace MediaInfoLib
 {
 
 //---------------------------------------------------------------------------
-void DashMpd_Transform (Ztring &Value, std::map<Ztring, Ztring> &Attributes)
+static void DashMpd_Transform (Ztring &Value, std::map<Ztring, Ztring> &Attributes)
 {
     size_t Pos1=0;
     for (;;)
@@ -78,7 +78,7 @@ void DashMpd_Transform (Ztring &Value, std::map<Ztring, Ztring> &Attributes)
 }
 
 //---------------------------------------------------------------------------
-stream_t DashMpd_mimeType_StreamKind (const char* mimeType)
+static stream_t DashMpd_mimeType_StreamKind (const char* mimeType)
 {
     Ztring StreamKind; StreamKind.From_UTF8(mimeType);
         if (StreamKind.find(__T("video"))==0)
@@ -92,7 +92,7 @@ stream_t DashMpd_mimeType_StreamKind (const char* mimeType)
 }
 
 //---------------------------------------------------------------------------
-Ztring DashMpd_codecid_CodecID (const char* codecid)
+static Ztring DashMpd_codecid_CodecID (const char* codecid)
 {
     Ztring CodecID;
 
@@ -155,6 +155,8 @@ struct template_generic
 
     template_generic(const template_generic &ToCopy)
     {
+        if (this == &ToCopy)
+            return;
         Sequence=new sequence;
         *Sequence=*ToCopy.Sequence;
         template_generic::BaseURL=ToCopy.BaseURL;
@@ -162,7 +164,7 @@ struct template_generic
         initialization=ToCopy.initialization;
         media=ToCopy.media;
         duration=ToCopy.duration;
-        startNumber=ToCopy.duration;
+        startNumber=ToCopy.startNumber;
         duration_Max=ToCopy.duration_Max;
         startNumber_Max=ToCopy.startNumber_Max;
     }
@@ -173,14 +175,14 @@ struct template_generic
     void Representation_Attributes_Parse    (XMLElement* Item);
 
     void Decode ();
+private:
+    template_generic &operator =(const template_generic &);
 };
 
 void template_generic::AdaptationSet_Attributes_Parse (XMLElement* Item)
 {
-    const char* Attribute;
-
     //Attributes - mineType
-    Attribute=Item->Attribute("mimeType");
+    const char* Attribute=Item->Attribute("mimeType");
     if (Attribute)
         Sequence->StreamKind=DashMpd_mimeType_StreamKind(Attribute);
 
@@ -197,10 +199,8 @@ void template_generic::AdaptationSet_Attributes_Parse (XMLElement* Item)
 
 void template_generic::SegmentTemplate_Attributes_Parse (XMLElement* Item)
 {
-    const char* Attribute;
-
     //Attributes - initialization
-    Attribute=Item->Attribute("initialization");
+    const char* Attribute=Item->Attribute("initialization");
     if (Attribute)
     {
         initialization.From_UTF8(Attribute);
@@ -230,11 +230,10 @@ void template_generic::SegmentTemplate_Attributes_Parse (XMLElement* Item)
 
 void template_generic::SegmentTimeline_Attributes_Parse (XMLElement* Item)
 {
-    const char* Attribute;
     segmenttimeline SegmentTimeLine;
 
     //Attributes - t (start time)
-    Attribute=Item->Attribute("t");
+    const char* Attribute=Item->Attribute("t");
     if (Attribute)
     {
         SegmentTimeLine.t=Ztring().From_UTF8(Attribute).To_int64u();
@@ -265,10 +264,8 @@ void template_generic::SegmentTimeline_Attributes_Parse (XMLElement* Item)
 
 void template_generic::Representation_Attributes_Parse (XMLElement* Item)
 {
-    const char* Attribute;
-
     //Attributes - id
-    Attribute=Item->Attribute("id");
+    const char* Attribute=Item->Attribute("id");
     if (Attribute)
     {
         Sequence->StreamID=Ztring().From_UTF8(Attribute).To_int64u(16);
@@ -380,10 +377,12 @@ void template_generic::Decode()
                         Media_Name_Temp.insert(Time_Pos, Index);
 
                     Ztring File_Name;
+                    Ztring File_Name_With_Path;
                     if (!SourceDir.empty())
-                        File_Name+=SourceDir+PathSeparator;
+                        File_Name_With_Path+=SourceDir+PathSeparator;
                     File_Name+=BaseURL+Media_Name_Temp;
-                    if (!File::Exists(File_Name))
+                    File_Name_With_Path+=BaseURL+Media_Name_Temp;
+                    if (!File::Exists(File_Name_With_Path))
                         break;
                     Sequence->AddFileName(File_Name);
                     Index_Pos_Temp++;
