@@ -38,6 +38,10 @@ using namespace std;
 namespace MediaInfoLib
 {
 
+//---------------------------------------------------------------------------
+extern string Jpeg2000_Rsiz(int16u Rsiz);
+//---------------------------------------------------------------------------
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -56,6 +60,8 @@ File_DcpCpl::File_DcpCpl()
 
     //Temp
     ReferenceFiles=NULL;
+    //PKL
+    PKL_Pos = (size_t)-1;
 }
 
 //---------------------------------------------------------------------------
@@ -156,6 +162,10 @@ bool File_DcpCpl::FileHeader_Begin()
     //Parsing main elements
     for (XMLElement* CompositionPlaylist_Item=Root->FirstChildElement(); CompositionPlaylist_Item; CompositionPlaylist_Item=CompositionPlaylist_Item->NextSiblingElement())
     {
+        const char* CompositionPlaylist_Item_Value=CompositionPlaylist_Item->Value();
+        if (!CompositionPlaylist_Item_Value)
+            continue;
+
         //CompositionTimecode
         if (IsImf && MatchQName(CompositionPlaylist_Item, "CompositionTimecode", NameSpace))
         {
@@ -208,6 +218,87 @@ bool File_DcpCpl::FileHeader_Begin()
                 Fill(Stream_Other, StreamPos_Last, Info->first.c_str(), Info->second);
         }
 
+        #if MEDIAINFO_ADVANCED
+            //EssenceDescriptorList
+            if (IsImf && !strcmp(CompositionPlaylist_Item_Value, "EssenceDescriptorList"))
+            {
+                for (XMLElement* EssenceDescriptorList_Item=CompositionPlaylist_Item->FirstChildElement(); EssenceDescriptorList_Item; EssenceDescriptorList_Item=EssenceDescriptorList_Item->NextSiblingElement())
+                {
+                const char* EssenceDescriptorList_Item_Value=EssenceDescriptorList_Item->Value();
+                if (!EssenceDescriptorList_Item_Value)
+                    continue;
+
+                    //TimecodeDropFrame
+                    if (!strcmp(EssenceDescriptorList_Item_Value, "EssenceDescriptor"))
+                    {
+                        string Id;
+                        descriptor* Descriptor=new descriptor;
+
+                        for (XMLElement* EssenceDescriptor_Item=EssenceDescriptorList_Item->FirstChildElement(); EssenceDescriptor_Item; EssenceDescriptor_Item=EssenceDescriptor_Item->NextSiblingElement())
+                        {
+                            const char* EssenceDescriptor_Item_Value=EssenceDescriptor_Item->Value();
+                            const char* EssenceDescriptor_Item_Text=EssenceDescriptor_Item->GetText();
+                            if (!EssenceDescriptor_Item_Value)
+                                continue;
+
+                            //Id
+                            if (EssenceDescriptor_Item_Text && !strcmp(EssenceDescriptor_Item_Value, "Id"))
+                                Id=EssenceDescriptor_Item_Text;
+
+                            //CDCIDescriptor
+                            if (!strcmp(EssenceDescriptor_Item_Value, "m:RGBADescriptor") || !strcmp(EssenceDescriptor_Item_Value, "m:CDCIDescriptor"))
+                            {
+                                for (XMLElement* Descriptor_Item=EssenceDescriptor_Item->FirstChildElement(); Descriptor_Item; Descriptor_Item=Descriptor_Item->NextSiblingElement())
+                                {
+                                    const char* Descriptor_Item_Value=Descriptor_Item->Value();
+                                    if (!Descriptor_Item_Value)
+                                        continue;
+
+                                    //SubDescriptors
+                                    if (!strcmp(Descriptor_Item_Value, "m:SubDescriptors"))
+                                    {
+                                        for (XMLElement* SubDescriptors_Item=Descriptor_Item->FirstChildElement(); SubDescriptors_Item; SubDescriptors_Item=SubDescriptors_Item->NextSiblingElement())
+                                        {
+                                            const char* SubDescriptors_Item_Value=SubDescriptors_Item->Value();
+                                            if (!SubDescriptors_Item_Value)
+                                                continue;
+
+                                            descriptor* SubDescriptor=new descriptor;
+
+                                            //JPEG2000PictureSubDescriptor
+                                            if (!strcmp(SubDescriptors_Item_Value, "m:JPEG2000PictureSubDescriptor"))
+                                            {
+                                                for (XMLElement* JPEG2000PictureSubDescriptor_Item=SubDescriptors_Item->FirstChildElement(); JPEG2000PictureSubDescriptor_Item; JPEG2000PictureSubDescriptor_Item=JPEG2000PictureSubDescriptor_Item->NextSiblingElement())
+                                                {
+                                                    const char* JPEG2000PictureSubDescriptor_Item_Value=JPEG2000PictureSubDescriptor_Item->Value();
+                                                    const char* JPEG2000PictureSubDescriptor_Item_Text=JPEG2000PictureSubDescriptor_Item->GetText();
+                                                    if (!JPEG2000PictureSubDescriptor_Item_Value || !JPEG2000PictureSubDescriptor_Item_Text)
+                                                        continue;
+
+                                                    //Xsiz
+                                                    if (!strcmp(JPEG2000PictureSubDescriptor_Item_Value, "m:Rsiz"))
+                                                    {
+                                                        SubDescriptor->Jpeg2000_Rsiz=(int16u)atoi(JPEG2000PictureSubDescriptor_Item_Text);
+                                                    }
+                                                }
+                                            }
+
+                                            Descriptor->SubDescriptors.push_back(SubDescriptor);
+                                        }
+                                    }
+                                }
+                            }
+                        }
+
+                        if (!Id.empty())
+                            EssenceDescriptorList[Id]=Descriptor;
+                        else
+                            delete Descriptor; // Can not be associated
+                    }
+                }
+            }
+        #endif //MEDIAINFO_ADVANCED
+
         //ReelList / SegmentList
         if (MatchQName(CompositionPlaylist_Item, IsDcp?"ReelList":"SegmentList", NameSpace))
         {
@@ -304,6 +395,12 @@ bool File_DcpCpl::FileHeader_Begin()
                                                         if (!strcmp(ResItemName, "SourceDuration"))
                                                             Resource->IgnoreEditsAfter=Resource->IgnoreEditsBefore+atoi(ResText);
 
+                                                        #if MEDIAINFO_ADVANCED
+                                                            //SourceEncoding
+                                                            if (!strcmp(ResItemName, "SourceEncoding"))
+                                                                Resource->SourceEncodings.push_back(ResText);
+                                                        #endif //MEDIAINFO_ADVANCED
+
                                                         //TrackFileId
                                                         if (!strcmp(ResItemName, "TrackFileId"))
                                                             Resource->FileNames.push_back(Ztring().From_UTF8(ResText));
@@ -373,6 +470,12 @@ bool File_DcpCpl::FileHeader_Begin()
 
     ReferenceFiles->FilesForStorage=true;
 
+    #if MEDIAINFO_ADVANCED
+        for (std::map<string, descriptor*>::iterator EssenceDescriptor = EssenceDescriptorList.begin(); EssenceDescriptor != EssenceDescriptorList.end(); ++EssenceDescriptor)
+            for (std::vector<descriptor*>::iterator SubDescriptor = EssenceDescriptor->second->SubDescriptors.begin(); SubDescriptor != EssenceDescriptor->second->SubDescriptors.end(); ++SubDescriptor)
+                ReferenceFiles->UpdateMetaDataFromSourceEncoding(EssenceDescriptor->first, "Format_Profile", Jpeg2000_Rsiz((*SubDescriptor)->Jpeg2000_Rsiz));
+    #endif //MEDIAINFO_ADVANCED
+
     //All should be OK...
     return true;
 }
