@@ -27,6 +27,7 @@
 #include "MediaInfo/MediaInfo.h"
 #include "MediaInfo/MediaInfo_Internal.h"
 #include "MediaInfo/Multiple/File__ReferenceFilesHelper.h"
+#include "MediaInfo/XmlUtils.h"
 #include "ZenLib/Dir.h"
 #include "ZenLib/File.h"
 #include "ZenLib/FileName.h"
@@ -114,22 +115,15 @@ bool File_DcpPkl::FileHeader_Begin()
     if (!FileHeader_Begin_XML(document))
        return false;
 
-    XMLElement* PackingList=document.FirstChildElement("PackingList");
-    if (!PackingList)
+    XMLElement* PackingList=document.FirstChildElement();
+    const char *NameSpace;
+    if (!PackingList || strcmp(LocalName(PackingList, NameSpace), "PackingList") || !NameSpace)
     {
         Reject("DcpPkl");
         return false;
     }
-
-    const char* Attribute=PackingList->Attribute("xmlns");
-    if (!Attribute)
-    {
-        Reject("DcpPkl");
-        return false;
-    }
-
-    if (strcmp(Attribute, "http://www.digicine.com/PROTO-ASDCP-PKL-20040311#")
-     && strcmp(Attribute, "http://www.smpte-ra.org/schemas/429-8/2007/PKL"))
+    if (strcmp(NameSpace, "http://www.digicine.com/PROTO-ASDCP-PKL-20040311#") &&
+        strcmp(NameSpace, "http://www.smpte-ra.org/schemas/429-8/2007/PKL"))
     {
         Reject("DcpPkl");
         return false;
@@ -143,37 +137,43 @@ bool File_DcpPkl::FileHeader_Begin()
     for (XMLElement* PackingList_Item=PackingList->FirstChildElement(); PackingList_Item; PackingList_Item=PackingList_Item->NextSiblingElement())
     {
         //AssetList
-        if (!strcmp(PackingList_Item->Value(), "AssetList"))
+        if (MatchQName(PackingList_Item, "AssetList", NameSpace))
         {
             for (XMLElement* AssetList_Item=PackingList_Item->FirstChildElement(); AssetList_Item; AssetList_Item=AssetList_Item->NextSiblingElement())
             {
                 //Asset
-                if (!strcmp(AssetList_Item->Value(), "Asset"))
+                if (MatchQName(AssetList_Item, "Asset", NameSpace))
                 {
                     stream Stream;
 
                     for (XMLElement* File_Item=AssetList_Item->FirstChildElement(); File_Item; File_Item=File_Item->NextSiblingElement())
                     {
+                        const char* Text=File_Item->GetText();
+                        const char *FileItemNs, *FileItemName = LocalName(File_Item, FileItemNs);
+                        if (!FileItemNs || strcmp(FileItemNs, NameSpace))
+                            continue; // item has wrong namespace
                         //AnnotationText
-                        if (!strcmp(File_Item->Value(), "AnnotationText"))
-                            Stream.AnnotationText=File_Item->GetText();
+                        if (Text && !strcmp(FileItemName, "AnnotationText"))
+                            Stream.AnnotationText=Text;
 
                         //Id
-                        if (!strcmp(File_Item->Value(), "Id"))
-                            Stream.Id=File_Item->GetText();
+                        if (Text && !strcmp(FileItemName, "Id"))
+                            Stream.Id=Text;
 
                         //OriginalFileName
-                        if (!strcmp(File_Item->Value(), "OriginalFileName"))
-                            Stream.OriginalFileName=File_Item->GetText();
+                        if (Text && !strcmp(FileItemName, "OriginalFileName"))
+                            Stream.OriginalFileName=Text;
 
                         //Type
-                        if (!strcmp(File_Item->Value(), "Type"))
+                        if (!strcmp(FileItemName, "Type"))
                         {
-                                 if (!strcmp(File_Item->GetText(), "application/x-smpte-mxf;asdcpKind=Picture"))
+                            if (!Text)
+                                Stream.StreamKind=Stream_Other;
+                            else if (!strcmp(Text, "application/x-smpte-mxf;asdcpKind=Picture"))
                                 Stream.StreamKind=Stream_Video;
-                            else if (!strcmp(File_Item->GetText(), "application/x-smpte-mxf;asdcpKind=Sound"))
+                            else if (!strcmp(Text, "application/x-smpte-mxf;asdcpKind=Sound"))
                                 Stream.StreamKind=Stream_Audio;
-                            else if (!strcmp(File_Item->GetText(), "text/xml") || !strcmp(File_Item->GetText(), "text/xml;asdcpKind=CPL"))
+                            else if (!strcmp(Text, "text/xml") || !strcmp(Text, "text/xml;asdcpKind=CPL"))
                                 Stream.StreamKind=(stream_t)(Stream_Max+1); // Means CPL
                             else
                                 Stream.StreamKind=Stream_Other;
@@ -191,7 +191,10 @@ bool File_DcpPkl::FileHeader_Begin()
     if (!Config->File_IsReferenced_Get())
     {
         FileName Directory(File_Name);
-        Ztring Assetmap_FileName=Directory.Path_Get()+PathSeparator+__T("ASSETMAP.xml");
+        Ztring DirPath = Directory.Path_Get();
+        if (!DirPath.empty())
+            DirPath += PathSeparator;
+        Ztring Assetmap_FileName=DirPath+__T("ASSETMAP.xml");
         bool IsOk=false;
         if (File::Exists(Assetmap_FileName))
             IsOk=true;
@@ -255,7 +258,11 @@ void File_DcpPkl::MergeFromAm (File_DcpPkl::streams &StreamsToMerge)
     {
         for (File_DcpPkl::streams::iterator StreamToMerge=StreamsToMerge.begin(); StreamToMerge!=StreamsToMerge.end(); ++StreamToMerge)
             if (StreamToMerge->Id==Stream->Id)
+            {
+                stream_t StreamKind=Stream->StreamKind; //Keeping StreamKind from PKL
                 *Stream=*StreamToMerge;
+                Stream->StreamKind=StreamKind; //Keeping StreamKind from PKL
+            }
     }
 }
 
