@@ -25,7 +25,6 @@
 #include <vector>
 #include <set>
 #include <bitset>
-using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -82,9 +81,9 @@ protected :
     void Streams_Finish_Essence_FillID (int32u EssenceUID, int128u TrackUID);
     void Streams_Finish_Descriptor (const int128u DescriptorUID, const int128u PackageUID);
     void Streams_Finish_Locator (const int128u DescriptorUID, const int128u LocatorUID);
-    void Streams_Finish_Component (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin);
-    void Streams_Finish_Component_ForTimeCode (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin, bool IsSourcePackage);
-    void Streams_Finish_Component_ForAS11 (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64u Origin);
+    void Streams_Finish_Component (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin);
+    void Streams_Finish_Component_ForTimeCode (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin, bool IsSourcePackage);
+    void Streams_Finish_Component_ForAS11 (const int128u ComponentUID, float64 EditRate, int32u TrackID, int64s Origin);
     void Streams_Finish_Identification (const int128u IdentificationUID);
     void Streams_Finish_CommercialNames ();
 
@@ -192,7 +191,7 @@ protected :
     void ClosedCompleteFooterPartition();
     void Primer();
     void IndexTableSegment();
-    void RandomIndexMetadata();
+    void RandomIndexPack();
     void SDTI_SystemMetadataPack();
     void SDTI_PackageMetadataSet();
     void SDTI_PictureMetadataSet();
@@ -420,6 +419,10 @@ protected :
     void LensUnitMetadata_LensZoomActualFocalLength();          //8005
     void LensUnitMetadata_OpticalExtenderMagnification();       //8006
     void LensUnitMetadata_LensAttributes();                     //8007
+    void LensUnitMetadata_IrisTNumber();                        //8008
+    void LensUnitMetadata_IrisRingPosition();                   //8009
+    void LensUnitMetadata_FocusRingPosition();                  //800A
+    void LensUnitMetadata_ZoomRingPosition();                   //800B
     void CameraUnitMetadata_CaptureGammaEquation();             //3210
     void CameraUnitMetadata_AutoExposureMode();                 //8100
     void CameraUnitMetadata_AutoFocusSensingAreaSetting();      //8101
@@ -445,6 +448,7 @@ protected :
     void CameraUnitMetadata_ExposureIndexofPhotoMeter();        //8115
     void CameraUnitMetadata_GammaForCDL();                      //8116
     void CameraUnitMetadata_ASC_CDL_V12();                      //8117
+    void CameraUnitMetadata_ColorMatrix();                      //8118
     void UserDefinedAcquisitionMetadata_UdamSetIdentifier();    //E000
     void UserDefinedAcquisitionMetadata_Sony_8007();
     void UserDefinedAcquisitionMetadata_Sony_E101();
@@ -544,33 +548,45 @@ protected :
     //TimeCode
     struct mxftimecode
     {
-        int16u  RoundedTimecodeBase;
         int64u  StartTimecode;
+        int16u  RoundedTimecodeBase;
         bool    DropFrame;
 
-        mxftimecode()
-            : RoundedTimecodeBase(0)
-            , StartTimecode((int64u)-1)
-            , DropFrame(false)
-        {
-        }
-
-        mxftimecode(int16u RoundedTimecodeBase_, int64u StartTimecode_, bool DropFrame_)
+        mxftimecode(int16u RoundedTimecodeBase_ = 0, int64u StartTimecode_ = (int64u)-1, bool DropFrame_ = false)
             : RoundedTimecodeBase(RoundedTimecodeBase_)
             , StartTimecode(StartTimecode_)
             , DropFrame(DropFrame_)
         {
         }
+        bool IsInit() const
+        {
+            return RoundedTimecodeBase && StartTimecode != (int64u)-1;
+        }
+        float64 Get_TimeCode_StartTimecode_Temp(const int64u& File_IgnoreEditsBefore) const
+        {
+            if (RoundedTimecodeBase)
+            {
+                float64 TimeCode_StartTimecode_Temp = ((float64)(StartTimecode + File_IgnoreEditsBefore)) / RoundedTimecodeBase;
+                if (DropFrame)
+                {
+                    TimeCode_StartTimecode_Temp *= 1001;
+                    TimeCode_StartTimecode_Temp /= 1000;
+                }
+                return TimeCode_StartTimecode_Temp;
+            }
+            else
+                return 0.0;
+        }
     };
 
     // Temp
-    struct randomindexmetadata
+    struct randomindexpack
     {
         int64u ByteOffset;
         int32u BodySID;
     };
-    std::vector<randomindexmetadata> RandomIndexMetadatas;
-    bool                             RandomIndexMetadatas_AlreadyParsed;
+    std::vector<randomindexpack>     RandomIndexPacks;
+    bool                             RandomIndexPacks_AlreadyParsed;
     std::set<int64u>                 PartitionPack_AlreadyParsed;
     size_t Streams_Count;
     int128u Code;
@@ -663,7 +679,7 @@ protected :
         int32u TrackNumber;
         float64 EditRate_Real; //Before demux adaptation
         float64 EditRate;
-        int64u  Origin;
+        int64s  Origin;
         bool   Stream_Finish_Done;
 
         track()
@@ -727,7 +743,7 @@ protected :
     };
     typedef std::map<int32u, essence> essences; //Key is TrackNumber
     essences Essences;
-    bitset<Stream_Max+1> StreamPos_StartAtZero; //information about the base of StreamPos (0 or 1, 1 is found in 1 file) TODO: per Essence code (last 4 bytes of the Essence header 0xTTXXTTXX)
+    std::bitset<Stream_Max+1> StreamPos_StartAtZero; //information about the base of StreamPos (0 or 1, 1 is found in 1 file) TODO: per Essence code (last 4 bytes of the Essence header 0xTTXXTTXX)
 
     //Descriptor
     struct descriptor
@@ -782,7 +798,9 @@ protected :
         bool HasMPEG2VideoDescriptor;
         bool IsAes3Descriptor;
         int32u ByteRate;
-
+        #if MEDIAINFO_ADVANCED
+            int16u Jpeg2000_Rsiz;
+        #endif //MEDIAINFO_ADVANCED
 
         //MCALabelSubDescriptor specific (including SoundfieldGroupLabelSubDescriptor...)
         int128u     MCALabelDictionaryID;
@@ -836,6 +854,9 @@ protected :
             HasMPEG2VideoDescriptor=false;
             IsAes3Descriptor=false;
             ByteRate=(int32u)-1;
+            #if MEDIAINFO_ADVANCED
+                Jpeg2000_Rsiz=(int16u)-1;
+            #endif //MEDIAINFO_ADVANCED
 
             //MCALabelSubDescriptor specific (including SoundfieldGroupLabelSubDescriptor...)
             MCALabelDictionaryID.hi=(int64u)-1;
@@ -850,6 +871,7 @@ protected :
     };
     typedef std::map<int128u, descriptor> descriptors; //Key is InstanceUID of Descriptor
     descriptors Descriptors;
+    void Descriptor_Fill(const char* Name, const Ztring& Value);
 
     //Locator
     struct locator
@@ -1048,6 +1070,7 @@ protected :
             CompletionDate=(int64u)-1;
             TextlessElementsExist=(int8u)-1;
             ProgrammeHasText=(int8u)-1;
+            FpaPass=(int8u)-1;
         }
 
         ~as11()
@@ -1101,14 +1124,14 @@ protected :
         inline void Locators_CleanUp() {}
         inline void Locators_Test() {}
     #endif //defined(MEDIAINFO_REFERENCES_YES)
-    void NextRandomIndexMetadata();
+    void NextRandomIndexPack();
     void TryToFinish();
 
     //Temp
     int128u EssenceContainer_FromPartitionMetadata;
     int64u PartitionMetadata_PreviousPartition;
     int64u PartitionMetadata_FooterPartition;
-    int64u RandomIndexMetadatas_MaxOffset;
+    int64u RandomIndexPacks_MaxOffset;
     mxftimecode MxfTimeCodeForDelay;
     mxftimecode MxfTimeCodeMaterial;
     float64 DTS_Delay; //In seconds
@@ -1198,7 +1221,7 @@ protected :
     };
     typedef std::vector<acquisitionmetadata> acquisitionmetadatalist;
     vector<acquisitionmetadatalist*> AcquisitionMetadataLists;
-    void AcquisitionMetadata_Add(size_t Id, string Value)
+    void AcquisitionMetadata_Add(size_t Id, const string& Value)
     {
         if (!AcquisitionMetadataLists[Id])
         {
@@ -1214,7 +1237,7 @@ protected :
         AcquisitionMetadataLists[Id]->push_back(acquisitionmetadata(Value));
     }
     vector<acquisitionmetadatalist*> AcquisitionMetadata_Sony_E201_Lists;
-    void AcquisitionMetadata_Sony_E201_Add(size_t Id, string Value)
+    void AcquisitionMetadata_Sony_E201_Add(size_t Id, const string& Value)
     {
         if (!AcquisitionMetadata_Sony_E201_Lists[Id])
         {
