@@ -96,7 +96,7 @@ void File_Ogg::Streams_Fill()
         ++Stream_Temp;
     }
 
-    Fill(Stream_General, 0, General_Format, "OGG", Unlimited, true, true);
+    Fill(Stream_General, 0, General_Format, "Ogg", Unlimited, true, true);
     if (Count_Get(Stream_Video)==0 && Count_Get(Stream_Image)==0)
         Fill(Stream_General, 0, General_InternetMediaType, "audio/ogg", Unlimited, true, true);
 }
@@ -343,7 +343,12 @@ void File_Ogg::Data_Parse()
 
             //Parsing
             if (continued || Parser->File_Offset!=Parser->File_Size)
-                Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, Chunk_Sizes[Chunk_Sizes_Pos]);
+            {
+                int64u Size=Chunk_Sizes[Chunk_Sizes_Pos];
+                if (Element_Offset+Size>Element_Size)
+                    Size=Element_Size-Element_Offset; // Shcunk size is bigger than content size, buggy file
+                Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, Size);
+            }
             if (Chunk_Sizes_Pos<Chunk_Sizes.size()-1
              || (Chunk_Sizes_Pos==Chunk_Sizes.size()-1 && Chunk_Sizes_Finished))
             {
