@@ -64,6 +64,30 @@ File_Rm::File_Rm()
     FromMKV_StreamType=Stream_Max;
 }
 
+//***************************************************************************
+// Buffer - File header
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+bool File_Rm::FileHeader_Begin()
+{
+    if (IsSub)
+        return true;
+
+    if (4>Buffer_Size)
+        return false;
+    if (Buffer[0]!=0x2E //".RMF"
+     || Buffer[1]!=0x52
+     || Buffer[2]!=0x4D
+     || Buffer[3]!=0x46)
+    {
+        Reject();
+        return false;
+    }
+
+    return true;
+}
+
 //***************************************************************************
 // Buffer
 //***************************************************************************
