@@ -30,6 +30,11 @@
     #undef __TEXT
     #include "windows.h"
 #endif // __WINDOWS__
+
+#if MEDIAINFO_EVENTS
+    #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
+    #include "MediaInfo/MediaInfo_Events_Internal.h"
+#endif //MEDIAINFO_EVENTS
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -40,7 +45,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_Caption_conversion_type(int8u Caption_conversion_type)
+static const char* AribStdB24B37_Caption_conversion_type(int8u Caption_conversion_type)
 {
     switch (Caption_conversion_type)
     {
@@ -54,7 +59,7 @@ const char* AribStdB24B37_Caption_conversion_type(int8u Caption_conversion_type)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_Caption_DataIdentifier(int8u DataIdentifier)
+static const char* AribStdB24B37_Caption_DataIdentifier(int8u DataIdentifier)
 {
     switch (DataIdentifier)
     {
@@ -71,7 +76,7 @@ const char* AribStdB24B37_Caption_DataIdentifier(int8u DataIdentifier)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_DRCS_conversion_type(int8u DRCS_conversion_type)
+static const char* AribStdB24B37_DRCS_conversion_type(int8u DRCS_conversion_type)
 {
     switch (DRCS_conversion_type)
     {
@@ -84,7 +89,7 @@ const char* AribStdB24B37_DRCS_conversion_type(int8u DRCS_conversion_type)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_data_group_id(int8u data_group_id)
+static const char* AribStdB24B37_data_group_id(int8u data_group_id)
 {
     switch (data_group_id)
     {
@@ -102,7 +107,7 @@ const char* AribStdB24B37_data_group_id(int8u data_group_id)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_TMD(int8u TMD)
+static const char* AribStdB24B37_TMD(int8u TMD)
 {
     switch (TMD)
     {
@@ -114,7 +119,7 @@ const char* AribStdB24B37_TMD(int8u TMD)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_DMF_reception(int8u DMF_reception)
+static const char* AribStdB24B37_DMF_reception(int8u DMF_reception)
 {
     switch (DMF_reception)
     {
@@ -127,7 +132,7 @@ const char* AribStdB24B37_DMF_reception(int8u DMF_reception)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_DMF_recording(int8u DMF_recording)
+static const char* AribStdB24B37_DMF_recording(int8u DMF_recording)
 {
     switch (DMF_recording)
     {
@@ -139,7 +144,7 @@ const char* AribStdB24B37_DMF_recording(int8u DMF_recording)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_format(int8u format)
+static const char* AribStdB24B37_format(int8u format)
 {
     switch (format)
     {
@@ -161,7 +166,7 @@ const char* AribStdB24B37_format(int8u format)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_TCS(int8u TCS)
+static const char* AribStdB24B37_TCS(int8u TCS)
 {
     switch (TCS)
     {
@@ -172,7 +177,7 @@ const char* AribStdB24B37_TCS(int8u TCS)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_rollup_mode(int8u rollup_mode)
+static const char* AribStdB24B37_rollup_mode(int8u rollup_mode)
 {
     switch (rollup_mode)
     {
@@ -183,7 +188,7 @@ const char* AribStdB24B37_rollup_mode(int8u rollup_mode)
 }
 
 //---------------------------------------------------------------------------
-const char* AribStdB24B37_data_unit_parameter(int8u data_unit_parameter)
+static const char* AribStdB24B37_data_unit_parameter(int8u data_unit_parameter)
 {
     switch (data_unit_parameter)
     {
@@ -248,7 +253,7 @@ static const int8u AribStdB24B37_DefaultMacros_size[] =
 // for each data byte do
 //     CRC_CCIT_Xmodem=(CRC_CCIT_Xmodem<<8) ^ CRC_CCIT_Xmodem_Table[(CRC_CCIT_Xmodem>>8)^(data_byte)];
 // Array built with the help of http://www.sanity-free.com/133/crc_16_ccitt_in_csharp.html
-int16u AribStdB24B37_CRC_CCIT_Xmodem_Table[256] =
+static int16u AribStdB24B37_CRC_CCIT_Xmodem_Table[256] =
 {
     0x0000, 0x1021, 0x2042, 0x3063,
     0x4084, 0x50A5, 0x60C6, 0x70E7,
@@ -335,6 +340,9 @@ File_AribStdB24B37::File_AribStdB24B37()
     HasCcis=false;
     ParseCcis=false;
     IsAncillaryData=false;
+    #if MEDIAINFO_EVENTS
+        MuxingMode=(int8u)-1;
+    #endif //MEDIAINFO_EVENTS
 
     //Config
     Caption_conversion_type=(int8u)-1;
@@ -722,6 +730,28 @@ void File_AribStdB24B37::caption_statement() //caption_data()
         Element_End0();
     }
 
+    // Output
+    #if MEDIAINFO_EVENTS
+            if (MuxingMode==(int8u)-1)
+            {
+                if (StreamIDs_Size>=6 && ParserIDs[StreamIDs_Size-6]==MediaInfo_Parser_Mxf && ParserIDs[StreamIDs_Size-3]==MediaInfo_Parser_MpegTs)
+                    MuxingMode=HasCcis?9:8; // "Ancillary data / CCIS" or "Ancillary data"
+                else
+                    MuxingMode=HasCcis?7:(int8u)-1; // "CCIS" or nothing
+            }
+        Frame_Count_NotParsedIncluded=Frame_Count;
+        EVENT_BEGIN (Global, SimpleText, 0)
+            Event.Content=Streams[(size_t)(Element_Code-1)].Line.c_str();
+            Event.Flags=0;
+            Event.MuxingMode=MuxingMode;
+            Event.Service=(int8u)Element_Code;
+            Event.Row_Max=0;
+            Event.Column_Max=0;
+            Event.Row_Values=NULL;
+            Event.Row_Attributes=NULL;
+        EVENT_END   ()
+    #endif //MEDIAINFO_EVENTS
+
     Frame_Count++;
     Frame_Count_NotParsedIncluded++;
 }
@@ -802,7 +832,7 @@ void File_AribStdB24B37::Add (Char Character)
 }
 
 //---------------------------------------------------------------------------
-void File_AribStdB24B37::Add (Ztring Character)
+void File_AribStdB24B37::Add (const Ztring& Character)
 {
     Streams[(size_t)(Element_Code-1)].Line+=Character;
 }
