@@ -40,15 +40,63 @@ using namespace std;
 namespace MediaInfoLib
 {
 
+using namespace FFV1;
+
 //***************************************************************************
 // Const
 //***************************************************************************
 
-extern int32u Psi_CRC_32_Table[256];
+extern const int32u Psi_CRC_32_Table[256];
 const int32u Slice::Context::N0 = 128;
 const int32s Slice::Context::Cmax = 127;
 const int32s Slice::Context::Cmin = -128;
 
+//***************************************************************************
+// Helpers
+//***************************************************************************
+
+//---------------------------------------------------------------------------
+static int32u FFv1_CRC_Compute(const int8u* Buffer, size_t Start, size_t Size)
+{
+    int32u CRC_32 = 0;
+    const int8u* CRC_32_Buffer=Buffer+Start;
+    const int8u* CRC_32_Buffer_End=CRC_32_Buffer+Size;
+
+    while(CRC_32_Buffer<CRC_32_Buffer_End)
+    {
+        CRC_32=(CRC_32<<8) ^ Psi_CRC_32_Table[(CRC_32>>24)^(*CRC_32_Buffer)];
+        CRC_32_Buffer++;
+    }
+    return CRC_32;
+}
+
+//---------------------------------------------------------------------------
+#if MEDIAINFO_FIXITY
+static size_t Ffv1_TryToFixCRC(const int8u* Buffer, size_t Buffer_Size)
+{
+    //looking for a bit flip
+    int8u* Buffer2=new int8u[Buffer_Size];
+    memcpy(Buffer2, Buffer, Buffer_Size);
+    vector<size_t> BitPositions;
+    size_t BitPosition_Max=Buffer_Size*8;
+    for (size_t BitPosition=0; BitPosition<BitPosition_Max; BitPosition++)
+    {
+        size_t BytePosition=BitPosition>>3;
+        size_t BitInBytePosition=BitPosition&0x7;
+        Buffer2[BytePosition]^=1<<BitInBytePosition;
+        int32u crc_left_New=FFv1_CRC_Compute(Buffer2, 0, Buffer_Size);
+        if (!crc_left_New)
+        {
+            BitPositions.push_back(BitPosition);
+        }
+        Buffer2[BytePosition]^=1<<BitInBytePosition;
+    }
+    delete[] Buffer2; //Buffer2=NULL
+
+    return BitPositions.size()==1?BitPositions[0]:(size_t)-1;
+}
+#endif //MEDIAINFO_FIXITY
+
 //***************************************************************************
 // RangeCoder
 //***************************************************************************
@@ -591,7 +639,7 @@ void File_Ffv1::Read_Buffer_OutOfBand()
 {
     ConfigurationRecordIsPresent=true;
 
-    int32u CRC_32=CRC_Compute((size_t)Element_Size);
+    int32u CRC_32=FFv1_CRC_Compute(Buffer+Buffer_Offset, (size_t)Element_Offset, (size_t)Element_Size);
 
     if (Buffer_Size < 4 || CRC_32)
     {
@@ -692,12 +740,13 @@ void File_Ffv1::Read_Buffer_Continue()
     for (size_t Pos = 0; Pos < Slices_BufferSizes.size(); Pos++)
     {
         Element_Begin1("Slice");
+        int64u Element_Offset_Begin=Element_Offset;
         int64u Element_Size_Save=Element_Size;
         Element_Size=Element_Offset+Slices_BufferSizes[Pos]-tail;
         int32u crc_left=0;
 
         if (error_correction == 1)
-            crc_left=CRC_Compute(Slices_BufferSizes[Pos]);
+            crc_left=FFv1_CRC_Compute(Buffer+Buffer_Offset, (size_t)Element_Offset, Slices_BufferSizes[Pos]);
 
         if (Pos)
         {
@@ -712,12 +761,10 @@ void File_Ffv1::Read_Buffer_Continue()
 #if MEDIAINFO_TRACE
         if (!Frame_Count || Trace_Activated) // Parse slice only if trace feature is activated
         {
-            int64u Start=Element_Offset;
-
             if (!slice(States))
             {
-                int64u SliceRealSize=Element_Offset-Start;
-                Element_Offset=Start;
+                int64u SliceRealSize=Element_Offset-Element_Offset_Begin;
+                Element_Offset=Element_Offset_Begin;
                 Skip_XX(SliceRealSize,                          "slice_data");
                 if (Trusted_Get() && !RC->Underrun() && Element_Offset==Element_Size)
                     Param_Info1("OK");
@@ -739,7 +786,24 @@ void File_Ffv1::Read_Buffer_Continue()
             if (!crc_left)
                 Param_Info1("OK");
             else
+            {
                 Param_Info1("NOK");
+
+                #if MEDIAINFO_FIXITY
+                    if (Config->TryToFix_Get())
+                    {
+                        size_t BitPosition=Ffv1_TryToFixCRC(Buffer+Buffer_Offset+(size_t)Element_Offset_Begin, Element_Offset-Element_Offset_Begin);
+                        if (BitPosition!=(size_t)-1)
+                        {
+                            size_t BytePosition=BitPosition>>3;
+                            size_t BitInBytePosition=BitPosition&0x7;
+                            int8u Modified=Buffer[Buffer_Offset+(size_t)Element_Offset_Begin+BytePosition];
+                            Modified^=1<<BitInBytePosition;
+                            FixFile(File_Offset+Buffer_Offset+(size_t)Element_Offset_Begin+BytePosition, &Modified, 1)?Param_Info1("Fixed"):Param_Info1("Not fixed");
+                        }
+                    }
+                #endif //MEDIAINFO_FIXITY
+            }
         }
         Element_End0();
     }
@@ -806,7 +870,7 @@ void File_Ffv1::FrameHeader()
     if (coder_type == 2) //Range coder with custom state transition table
     {
         Element_Begin1("state_transition_deltas");
-        for (int16u i = 1; i < state_transitions_size; i++)
+        for (size_t i = 1; i < state_transitions_size; i++)
         {
             int32s state_transition_delta;
             Get_RS (States, state_transition_delta,             "state_transition_delta");
@@ -863,7 +927,7 @@ void File_Ffv1::FrameHeader()
             context_count[i] = context_count[0];
         }
     }
-    memset(quant_tables+quant_table_count, 0x00, (MAX_QUANT_TABLES-quant_table_count)*MAX_CONTEXT_INPUTS*256*sizeof(int16s));
+    memset(quant_tables+quant_table_count, 0x00, (MAX_QUANT_TABLES-quant_table_count)*MAX_CONTEXT_INPUTS*256*sizeof(pixel_t));
 
     for (size_t i = 0; i < quant_table_count; i++)
     {
@@ -916,6 +980,9 @@ void File_Ffv1::FrameHeader()
             Get_RU (States, intra,                              "intra");
     }
 
+    //Marking handling of 16-bit overflow computing
+    is_overflow_16bit=(colorspace_type==0 && bits_per_raw_sample==16 && (coder_type==1 || coder_type==2))?true:false; //TODO: check in FFmpeg the version when the stream is fixed. Note: only with YUV colorspace
+
     FILLING_BEGIN();
         if (Frame_Count==0)
         {
@@ -1050,10 +1117,13 @@ int File_Ffv1::slice(states &States)
     if (!coder_type && ((version == 3 && micro_version > 1) || version > 3))
         BS_End();
 
-    if (coder_type && version > 2)
+    if (coder_type)
     {
-        int8u s = 129;
-        RC->get_rac(&s);
+        if (version > 2)
+        {
+            int8u s = 129;
+            RC->get_rac(&s);
+        }
         Element_Offset+=RC->BytesUsed();
     }
 
@@ -1149,7 +1219,7 @@ void File_Ffv1::plane(int32u pos)
     bits_mask2 = 1 << (bits_max - 1);
     bits_mask3 = bits_mask2 - 1;
 
-    int16s *sample[2];
+    pixel_t *sample[2];
     sample[0] = current_slice->sample_buffer + 3;
     sample[1] = sample[0] + current_slice->w + 6;
 
@@ -1195,7 +1265,7 @@ void File_Ffv1::rgb()
 
     size_t c_max = alpha_plane ? 4 : 3;
 
-    int16s *sample[4][2];
+    pixel_t *sample[4][2];
 
     current_slice->run_index = 0;
 
@@ -1262,17 +1332,27 @@ static inline int32s get_median_number(int32s one, int32s two, int32s three)
 }
 
 //---------------------------------------------------------------------------
-static inline int32s predict(int16s *current, int16s *current_top)
+static inline int32s predict(pixel_t *current, pixel_t *current_top, bool is_overflow_16bit)
 {
-    int32s LeftTop = current_top[-1];
-    int32s Top = current_top[0];
-    int32s Left = current[-1];
+    int32s LeftTop, Top, Left;
+    if (is_overflow_16bit)
+    {
+        LeftTop = (int16s)current_top[-1];
+        Top = (int16s)current_top[0];
+        Left = (int16s)current[-1];
+    }
+    else
+    {
+        LeftTop = current_top[-1];
+        Top = current_top[0];
+        Left = current[-1];
+    }
 
     return get_median_number(Left, Left + Top - LeftTop, Top);
 }
 
 //---------------------------------------------------------------------------
-static inline int get_context_3(int16s quant_table[MAX_CONTEXT_INPUTS][256], int16s *src, int16s *last)
+static inline int get_context_3(pixel_t quant_table[MAX_CONTEXT_INPUTS][256], pixel_t *src, pixel_t *last)
 {
     const int LT = last[-1];
     const int T  = last[0];
@@ -1283,7 +1363,7 @@ static inline int get_context_3(int16s quant_table[MAX_CONTEXT_INPUTS][256], int
         + quant_table[1][(LT - T) & 0xFF]
         + quant_table[2][(T - RT) & 0xFF];
 }
-static inline int get_context_5(int16s quant_table[MAX_CONTEXT_INPUTS][256], int16s *src, int16s *last)
+static inline int get_context_5(pixel_t quant_table[MAX_CONTEXT_INPUTS][256], pixel_t *src, pixel_t *last)
 {
     const int LT = last[-1];
     const int T  = last[0];
@@ -1420,15 +1500,15 @@ int32s File_Ffv1::pixel_GR(int32s context)
 }
 
 //---------------------------------------------------------------------------
-void File_Ffv1::line(int pos, int16s *sample[2])
+void File_Ffv1::line(int pos, pixel_t *sample[2])
 {
     // TODO: slice_coding_mode (version 4)
 
     quant_table_struct& quant_table = quant_tables[quant_table_index[pos]];
     bool Is5 = quant_table[3][127] ? true : false;
-    int16s* s0c = sample[0];
-    int16s* s0e = s0c + current_slice->w;
-    int16s* s1c = sample[1];
+    pixel_t* s0c = sample[0];
+    pixel_t* s0e = s0c + current_slice->w;
+    pixel_t* s1c = sample[1];
 
     if (coder_type)
     {
@@ -1438,7 +1518,7 @@ void File_Ffv1::line(int pos, int16s *sample[2])
         {
             int32s context = Is5 ? get_context_5(quant_table, s1c, s0c) : get_context_3(quant_table, s1c, s0c);
 
-            int32s Value = predict(s1c, s0c);
+            int32s Value = predict(s1c, s0c, is_overflow_16bit);
             #if MEDIAINFO_TRACE_FFV1CONTENT
                 if (context >= 0)
                     Value += pixel_RC(context);
@@ -1467,7 +1547,7 @@ void File_Ffv1::line(int pos, int16s *sample[2])
         {
             int32s context = Is5 ? get_context_5(quant_table, s1c, s0c) : get_context_3(quant_table, s1c, s0c);
 
-            *s1c = (predict(s1c, s0c) + (context >= 0 ? pixel_GR(context) : -pixel_GR(-context))) & bits_mask1;
+            *s1c = (predict(s1c, s0c, is_overflow_16bit) + (context >= 0 ? pixel_GR(context) : -pixel_GR(-context))) & bits_mask1;
 
             s0c++;
             s1c++;
@@ -1520,7 +1600,7 @@ void File_Ffv1::read_quant_table(int i, int j, size_t scale)
             return;
         }
 
-        for (size_t a=0; a<=len_minus1; a++)
+        for (int32u a=0; a<=len_minus1; a++)
         {
             quant_tables[i][j][k] = scale * v;
             k++;
@@ -1542,21 +1622,6 @@ void File_Ffv1::read_quant_table(int i, int j, size_t scale)
 // Helpers
 //***************************************************************************
 
-//---------------------------------------------------------------------------
-int32u File_Ffv1::CRC_Compute(size_t Size)
-{
-    int32u CRC_32=0;
-    const int8u* CRC_32_Buffer=Buffer+Buffer_Offset+(size_t)Element_Offset;
-    const int8u* CRC_32_Buffer_End=CRC_32_Buffer+Size;
-
-    while(CRC_32_Buffer<CRC_32_Buffer_End)
-    {
-        CRC_32=(CRC_32<<8) ^ Psi_CRC_32_Table[(CRC_32>>24)^(*CRC_32_Buffer)];
-        CRC_32_Buffer++;
-    }
-    return CRC_32;
-}
-
 //---------------------------------------------------------------------------
 int32s File_Ffv1::golomb_rice_decode(int k)
 {
